# meiga 🧙 

[![version](https://img.shields.io/github/release/alice-biometrics/meiga/all.svg)](https://github.com/alice-biometrics/meiga/releases) 
[![ci](https://github.com/alice-biometrics/meiga/workflows/ci/badge.svg)](https://github.com/alice-biometrics/meiga/actions) 
[![pypi](https://img.shields.io/pypi/dm/meiga)](https://pypi.org/project/meiga/) 
[![codecov](https://codecov.io/gh/alice-biometrics/meiga/branch/main/graph/badge.svg?token=BX1IZJZLJQ)](https://codecov.io/gh/alice-biometrics/meiga)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Imports: isort](https://img.shields.io/badge/%20imports-isort-%231674b1?style=flat&labelColor=ef8336)](https://pycqa.github.io/isort/)
[![license](https://img.shields.io/github/license/alice-biometrics/meiga.svg)](https://github.com/alice-biometrics/meiga/blob/main/LICENSE)
[![versions](https://img.shields.io/pypi/pyversions/meiga.svg)](https://github.com/alice-biometrics/meiga)

<img src="https://github.com/alice-biometrics/custom-emojis/blob/master/images/alice_header.png?raw=true" width=auto>

---

**Documentation**: <a href="https://alice-biometrics.github.io/meiga/" target="_blank">https://alice-biometrics.github.io/meiga/</a>

**Source Code**: <a href="https://github.com/alice-biometrics/meiga" target="_blank">https://github.com/alice-biometrics/meiga</a>

---

## What is meiga 🧙?

`meiga 🧙` is a Python µframework that provides a simple, fully typed, monad-based result type ➡️ `Result[Value, Error]`.

## How could meiga 🧙 help me?

`meiga 🧙` provides a simple and clear way of handling errors in Python without using `Exceptions`. This package improves the Dev Experience as it allows to know all possible typed responses. With Meiga 🧙 your IDE will help you much more. 

## Installation 💻

```console
pip install meiga
```

## Contribute 

We'd love you to contribute to *meiga* 🥳🥳🥳🥳🥳🥳️️!

For more information, check our [documentation](https://alice-biometrics.github.io/meiga/contributing/)

## Contact 📬

support@alicebiometrics.com
